Class: Grafeas::V1::CISAKnownExploitedVulnerabilities

Inherits:
Object
  • Object
show all
Extended by:
Google::Protobuf::MessageExts::ClassMethods
Includes:
Google::Protobuf::MessageExts
Defined in:
proto_docs/grafeas/v1/risk.rb

Instance Attribute Summary collapse

Instance Attribute Details

#known_ransomware_campaign_use::String

Returns Whether the vulnerability is known to have been leveraged as part of a ransomware campaign.

Returns:

  • (::String)

    Whether the vulnerability is known to have been leveraged as part of a ransomware campaign.



39
40
41
42
# File 'proto_docs/grafeas/v1/risk.rb', line 39

class CISAKnownExploitedVulnerabilities
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end