Class: Grafeas::V1::CloudRepoSourceContext

Inherits:
Object
  • Object
show all
Extended by:
Google::Protobuf::MessageExts::ClassMethods
Includes:
Google::Protobuf::MessageExts
Defined in:
proto_docs/grafeas/v1/provenance.rb

Overview

A CloudRepoSourceContext denotes a particular revision in a Google Cloud Source Repo.

Instance Attribute Summary collapse

Instance Attribute Details

#alias_context::Grafeas::V1::AliasContext

Returns An alias, which may be a branch or tag.

Note: The following fields are mutually exclusive: alias_context, revision_id. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Grafeas::V1::AliasContext)

    An alias, which may be a branch or tag.

    Note: The following fields are mutually exclusive: alias_context, revision_id. If a field in that set is populated, all other fields in the set will automatically be cleared.



265
266
267
268
# File 'proto_docs/grafeas/v1/provenance.rb', line 265

class CloudRepoSourceContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#repo_id::Grafeas::V1::RepoId

Returns The ID of the repo.

Returns:



265
266
267
268
# File 'proto_docs/grafeas/v1/provenance.rb', line 265

class CloudRepoSourceContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#revision_id::String

Returns A revision ID.

Note: The following fields are mutually exclusive: revision_id, alias_context. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    A revision ID.

    Note: The following fields are mutually exclusive: revision_id, alias_context. If a field in that set is populated, all other fields in the set will automatically be cleared.



265
266
267
268
# File 'proto_docs/grafeas/v1/provenance.rb', line 265

class CloudRepoSourceContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end