Class: Grafeas::V1::ComplianceVersion
- Inherits:
-
Object
- Object
- Grafeas::V1::ComplianceVersion
- Extended by:
- Google::Protobuf::MessageExts::ClassMethods
- Includes:
- Google::Protobuf::MessageExts
- Defined in:
- proto_docs/grafeas/v1/compliance.rb
Overview
Describes the CIS benchmark version that is applicable to a given OS and os version.
Instance Attribute Summary collapse
-
#cpe_uri ⇒ ::String
The CPE URI (https://cpe.mitre.org/specification/) this benchmark is applicable to.
-
#version ⇒ ::String
The version of the benchmark.
Instance Attribute Details
#cpe_uri ⇒ ::String
Returns The CPE URI (https://cpe.mitre.org/specification/) this benchmark is applicable to.
67 68 69 70 |
# File 'proto_docs/grafeas/v1/compliance.rb', line 67 class ComplianceVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#version ⇒ ::String
Returns The version of the benchmark. This is set to the version of the OS-specific CIS document the benchmark is defined in.
67 68 69 70 |
# File 'proto_docs/grafeas/v1/compliance.rb', line 67 class ComplianceVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |