Class: Grafeas::V1::GerritSourceContext

Inherits:
Object
  • Object
show all
Extended by:
Google::Protobuf::MessageExts::ClassMethods
Includes:
Google::Protobuf::MessageExts
Defined in:
proto_docs/grafeas/v1/provenance.rb

Overview

A SourceContext referring to a Gerrit project.

Instance Attribute Summary collapse

Instance Attribute Details

#alias_context::Grafeas::V1::AliasContext

Returns An alias, which may be a branch or tag.

Note: The following fields are mutually exclusive: alias_context, revision_id. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Grafeas::V1::AliasContext)

    An alias, which may be a branch or tag.

    Note: The following fields are mutually exclusive: alias_context, revision_id. If a field in that set is populated, all other fields in the set will automatically be cleared.



289
290
291
292
# File 'proto_docs/grafeas/v1/provenance.rb', line 289

class GerritSourceContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#gerrit_project::String

Returns The full project name within the host. Projects may be nested, so "project/subproject" is a valid project name. The "repo name" is the hostURI/project.

Returns:

  • (::String)

    The full project name within the host. Projects may be nested, so "project/subproject" is a valid project name. The "repo name" is the hostURI/project.



289
290
291
292
# File 'proto_docs/grafeas/v1/provenance.rb', line 289

class GerritSourceContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#host_uri::String

Returns The URI of a running Gerrit instance.

Returns:

  • (::String)

    The URI of a running Gerrit instance.



289
290
291
292
# File 'proto_docs/grafeas/v1/provenance.rb', line 289

class GerritSourceContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#revision_id::String

Returns A revision (commit) ID.

Note: The following fields are mutually exclusive: revision_id, alias_context. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    A revision (commit) ID.

    Note: The following fields are mutually exclusive: revision_id, alias_context. If a field in that set is populated, all other fields in the set will automatically be cleared.



289
290
291
292
# File 'proto_docs/grafeas/v1/provenance.rb', line 289

class GerritSourceContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end