Class: Grafeas::V1::ListNotesResponse

Inherits:
Object
  • Object
show all
Extended by:
Google::Protobuf::MessageExts::ClassMethods
Includes:
Google::Protobuf::MessageExts
Defined in:
proto_docs/grafeas/v1/grafeas.rb

Overview

Response for listing notes.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns The next pagination token in the list response. It should be used as page_token for the following request. An empty value means no more results.

Returns:

  • (::String)

    The next pagination token in the list response. It should be used as page_token for the following request. An empty value means no more results.



379
380
381
382
# File 'proto_docs/grafeas/v1/grafeas.rb', line 379

class ListNotesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#notes::Array<::Grafeas::V1::Note>

Returns The notes requested.

Returns:



379
380
381
382
# File 'proto_docs/grafeas/v1/grafeas.rb', line 379

class ListNotesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String>

Returns Unreachable regions. Populated for requests from the global region when return_partial_success is set.

Format: projects/[PROJECT_ID]/locations/[LOCATION].

Returns:

  • (::Array<::String>)

    Unreachable regions. Populated for requests from the global region when return_partial_success is set.

    Format: projects/[PROJECT_ID]/locations/[LOCATION]



379
380
381
382
# File 'proto_docs/grafeas/v1/grafeas.rb', line 379

class ListNotesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end