Class: Grafeas::V1::ListOccurrencesRequest

Inherits:
Object
  • Object
show all
Extended by:
Google::Protobuf::MessageExts::ClassMethods
Includes:
Google::Protobuf::MessageExts
Defined in:
proto_docs/grafeas/v1/grafeas.rb

Overview

Request to list occurrences.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns The filter expression.

Returns:

  • (::String)

    The filter expression.



253
254
255
256
# File 'proto_docs/grafeas/v1/grafeas.rb', line 253

class ListOccurrencesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Number of occurrences to return in the list. Must be positive. Max allowed page size is 1000. If not specified, page size defaults to 20.

Returns:

  • (::Integer)

    Number of occurrences to return in the list. Must be positive. Max allowed page size is 1000. If not specified, page size defaults to 20.



253
254
255
256
# File 'proto_docs/grafeas/v1/grafeas.rb', line 253

class ListOccurrencesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Token to provide to skip to a particular spot in the list.

Returns:

  • (::String)

    Token to provide to skip to a particular spot in the list.



253
254
255
256
# File 'proto_docs/grafeas/v1/grafeas.rb', line 253

class ListOccurrencesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns The name of the project to list occurrences for in the form of projects/[PROJECT_ID].

Returns:

  • (::String)

    The name of the project to list occurrences for in the form of projects/[PROJECT_ID].



253
254
255
256
# File 'proto_docs/grafeas/v1/grafeas.rb', line 253

class ListOccurrencesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#return_partial_success::Boolean

Returns If set, the request will return all reachable Occurrences and report all unreachable regions in the unreachable field in the response.

Only applicable for requests in the global region.

Returns:

  • (::Boolean)

    If set, the request will return all reachable Occurrences and report all unreachable regions in the unreachable field in the response.

    Only applicable for requests in the global region.



253
254
255
256
# File 'proto_docs/grafeas/v1/grafeas.rb', line 253

class ListOccurrencesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end