Class: Grafeas::V1::Note

Inherits:
Object
  • Object
show all
Extended by:
Google::Protobuf::MessageExts::ClassMethods
Includes:
Google::Protobuf::MessageExts
Defined in:
proto_docs/grafeas/v1/grafeas.rb

Overview

A type of analysis that can be done for a resource.

Instance Attribute Summary collapse

Instance Attribute Details

#attestation::Grafeas::V1::AttestationNote

Returns A note describing an attestation role.

Note: The following fields are mutually exclusive: attestation, vulnerability, build, image, package, deployment, discovery, upgrade, compliance, dsse_attestation, vulnerability_assessment, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Grafeas::V1::AttestationNote)

    A note describing an attestation role.

    Note: The following fields are mutually exclusive: attestation, vulnerability, build, image, package, deployment, discovery, upgrade, compliance, dsse_attestation, vulnerability_assessment, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.



216
217
218
219
# File 'proto_docs/grafeas/v1/grafeas.rb', line 216

class Note
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#build::Grafeas::V1::BuildNote

Returns A note describing build provenance for a verifiable build.

Note: The following fields are mutually exclusive: build, vulnerability, image, package, deployment, discovery, attestation, upgrade, compliance, dsse_attestation, vulnerability_assessment, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Grafeas::V1::BuildNote)

    A note describing build provenance for a verifiable build.

    Note: The following fields are mutually exclusive: build, vulnerability, image, package, deployment, discovery, attestation, upgrade, compliance, dsse_attestation, vulnerability_assessment, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.



216
217
218
219
# File 'proto_docs/grafeas/v1/grafeas.rb', line 216

class Note
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#compliance::Grafeas::V1::ComplianceNote

Returns A note describing a compliance check.

Note: The following fields are mutually exclusive: compliance, vulnerability, build, image, package, deployment, discovery, attestation, upgrade, dsse_attestation, vulnerability_assessment, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Grafeas::V1::ComplianceNote)

    A note describing a compliance check.

    Note: The following fields are mutually exclusive: compliance, vulnerability, build, image, package, deployment, discovery, attestation, upgrade, dsse_attestation, vulnerability_assessment, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.



216
217
218
219
# File 'proto_docs/grafeas/v1/grafeas.rb', line 216

class Note
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#create_time::Google::Protobuf::Timestamp

Returns Output only. The time this note was created. This field can be used as a filter in list requests.

Returns:



216
217
218
219
# File 'proto_docs/grafeas/v1/grafeas.rb', line 216

class Note
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#deployment::Grafeas::V1::DeploymentNote

Returns A note describing something that can be deployed.

Note: The following fields are mutually exclusive: deployment, vulnerability, build, image, package, discovery, attestation, upgrade, compliance, dsse_attestation, vulnerability_assessment, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Grafeas::V1::DeploymentNote)

    A note describing something that can be deployed.

    Note: The following fields are mutually exclusive: deployment, vulnerability, build, image, package, discovery, attestation, upgrade, compliance, dsse_attestation, vulnerability_assessment, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.



216
217
218
219
# File 'proto_docs/grafeas/v1/grafeas.rb', line 216

class Note
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#discovery::Grafeas::V1::DiscoveryNote

Returns A note describing the initial analysis of a resource.

Note: The following fields are mutually exclusive: discovery, vulnerability, build, image, package, deployment, attestation, upgrade, compliance, dsse_attestation, vulnerability_assessment, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Grafeas::V1::DiscoveryNote)

    A note describing the initial analysis of a resource.

    Note: The following fields are mutually exclusive: discovery, vulnerability, build, image, package, deployment, attestation, upgrade, compliance, dsse_attestation, vulnerability_assessment, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.



216
217
218
219
# File 'proto_docs/grafeas/v1/grafeas.rb', line 216

class Note
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#dsse_attestation::Grafeas::V1::DSSEAttestationNote

Returns A note describing a dsse attestation note.

Note: The following fields are mutually exclusive: dsse_attestation, vulnerability, build, image, package, deployment, discovery, attestation, upgrade, compliance, vulnerability_assessment, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Grafeas::V1::DSSEAttestationNote)

    A note describing a dsse attestation note.

    Note: The following fields are mutually exclusive: dsse_attestation, vulnerability, build, image, package, deployment, discovery, attestation, upgrade, compliance, vulnerability_assessment, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.



216
217
218
219
# File 'proto_docs/grafeas/v1/grafeas.rb', line 216

class Note
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#expiration_time::Google::Protobuf::Timestamp

Returns Time of expiration for this note. Empty if note does not expire.

Returns:



216
217
218
219
# File 'proto_docs/grafeas/v1/grafeas.rb', line 216

class Note
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#image::Grafeas::V1::ImageNote

Returns A note describing a base image.

Note: The following fields are mutually exclusive: image, vulnerability, build, package, deployment, discovery, attestation, upgrade, compliance, dsse_attestation, vulnerability_assessment, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Grafeas::V1::ImageNote)

    A note describing a base image.

    Note: The following fields are mutually exclusive: image, vulnerability, build, package, deployment, discovery, attestation, upgrade, compliance, dsse_attestation, vulnerability_assessment, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.



216
217
218
219
# File 'proto_docs/grafeas/v1/grafeas.rb', line 216

class Note
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#kind::Grafeas::V1::NoteKind

Returns Output only. The type of analysis. This field can be used as a filter in list requests.

Returns:

  • (::Grafeas::V1::NoteKind)

    Output only. The type of analysis. This field can be used as a filter in list requests.



216
217
218
219
# File 'proto_docs/grafeas/v1/grafeas.rb', line 216

class Note
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#long_description::String

Returns A detailed description of this note.

Returns:

  • (::String)

    A detailed description of this note.



216
217
218
219
# File 'proto_docs/grafeas/v1/grafeas.rb', line 216

class Note
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Output only. The name of the note in the form of projects/[PROVIDER_ID]/notes/[NOTE_ID].

Returns:

  • (::String)

    Output only. The name of the note in the form of projects/[PROVIDER_ID]/notes/[NOTE_ID].



216
217
218
219
# File 'proto_docs/grafeas/v1/grafeas.rb', line 216

class Note
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#package::Grafeas::V1::PackageNote

Returns A note describing a package hosted by various package managers.

Note: The following fields are mutually exclusive: package, vulnerability, build, image, deployment, discovery, attestation, upgrade, compliance, dsse_attestation, vulnerability_assessment, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Grafeas::V1::PackageNote)

    A note describing a package hosted by various package managers.

    Note: The following fields are mutually exclusive: package, vulnerability, build, image, deployment, discovery, attestation, upgrade, compliance, dsse_attestation, vulnerability_assessment, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.



216
217
218
219
# File 'proto_docs/grafeas/v1/grafeas.rb', line 216

class Note
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

Returns Other notes related to this note.

Returns:

  • (::Array<::String>)

    Other notes related to this note.



216
217
218
219
# File 'proto_docs/grafeas/v1/grafeas.rb', line 216

class Note
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

Returns URLs associated with this note.

Returns:



216
217
218
219
# File 'proto_docs/grafeas/v1/grafeas.rb', line 216

class Note
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sbom_reference::Grafeas::V1::SBOMReferenceNote

Returns A note describing an SBOM reference.

Note: The following fields are mutually exclusive: sbom_reference, vulnerability, build, image, package, deployment, discovery, attestation, upgrade, compliance, dsse_attestation, vulnerability_assessment, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Grafeas::V1::SBOMReferenceNote)

    A note describing an SBOM reference.

    Note: The following fields are mutually exclusive: sbom_reference, vulnerability, build, image, package, deployment, discovery, attestation, upgrade, compliance, dsse_attestation, vulnerability_assessment, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.



216
217
218
219
# File 'proto_docs/grafeas/v1/grafeas.rb', line 216

class Note
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#secret::Grafeas::V1::SecretNote

Returns A note describing a secret.

Note: The following fields are mutually exclusive: secret, vulnerability, build, image, package, deployment, discovery, attestation, upgrade, compliance, dsse_attestation, vulnerability_assessment, sbom_reference. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Grafeas::V1::SecretNote)

    A note describing a secret.

    Note: The following fields are mutually exclusive: secret, vulnerability, build, image, package, deployment, discovery, attestation, upgrade, compliance, dsse_attestation, vulnerability_assessment, sbom_reference. If a field in that set is populated, all other fields in the set will automatically be cleared.



216
217
218
219
# File 'proto_docs/grafeas/v1/grafeas.rb', line 216

class Note
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#short_description::String

Returns A one sentence description of this note.

Returns:

  • (::String)

    A one sentence description of this note.



216
217
218
219
# File 'proto_docs/grafeas/v1/grafeas.rb', line 216

class Note
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_time::Google::Protobuf::Timestamp

Returns Output only. The time this note was last updated. This field can be used as a filter in list requests.

Returns:



216
217
218
219
# File 'proto_docs/grafeas/v1/grafeas.rb', line 216

class Note
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#upgrade::Grafeas::V1::UpgradeNote

Returns A note describing available package upgrades.

Note: The following fields are mutually exclusive: upgrade, vulnerability, build, image, package, deployment, discovery, attestation, compliance, dsse_attestation, vulnerability_assessment, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Grafeas::V1::UpgradeNote)

    A note describing available package upgrades.

    Note: The following fields are mutually exclusive: upgrade, vulnerability, build, image, package, deployment, discovery, attestation, compliance, dsse_attestation, vulnerability_assessment, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.



216
217
218
219
# File 'proto_docs/grafeas/v1/grafeas.rb', line 216

class Note
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#vulnerability::Grafeas::V1::VulnerabilityNote

Returns A note describing a package vulnerability.

Note: The following fields are mutually exclusive: vulnerability, build, image, package, deployment, discovery, attestation, upgrade, compliance, dsse_attestation, vulnerability_assessment, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Grafeas::V1::VulnerabilityNote)

    A note describing a package vulnerability.

    Note: The following fields are mutually exclusive: vulnerability, build, image, package, deployment, discovery, attestation, upgrade, compliance, dsse_attestation, vulnerability_assessment, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.



216
217
218
219
# File 'proto_docs/grafeas/v1/grafeas.rb', line 216

class Note
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#vulnerability_assessment::Grafeas::V1::VulnerabilityAssessmentNote

Returns A note describing a vulnerability assessment.

Note: The following fields are mutually exclusive: vulnerability_assessment, vulnerability, build, image, package, deployment, discovery, attestation, upgrade, compliance, dsse_attestation, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Grafeas::V1::VulnerabilityAssessmentNote)

    A note describing a vulnerability assessment.

    Note: The following fields are mutually exclusive: vulnerability_assessment, vulnerability, build, image, package, deployment, discovery, attestation, upgrade, compliance, dsse_attestation, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.



216
217
218
219
# File 'proto_docs/grafeas/v1/grafeas.rb', line 216

class Note
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end