Class: Grafeas::V1::SecretOccurrence

Inherits:
Object
  • Object
show all
Extended by:
Google::Protobuf::MessageExts::ClassMethods
Includes:
Google::Protobuf::MessageExts
Defined in:
proto_docs/grafeas/v1/secret.rb

Overview

The occurrence provides details of a secret.

Instance Attribute Summary collapse

Instance Attribute Details

#data::Google::Protobuf::Any

Returns Scan result of the secret.

Returns:



45
46
47
48
# File 'proto_docs/grafeas/v1/secret.rb', line 45

class SecretOccurrence
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#digest::Grafeas::V1::Digest

Returns Hash value, typically a digest for the secret data, that allows unique identification of a specific secret.

Returns:

  • (::Grafeas::V1::Digest)

    Hash value, typically a digest for the secret data, that allows unique identification of a specific secret.



45
46
47
48
# File 'proto_docs/grafeas/v1/secret.rb', line 45

class SecretOccurrence
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#kind::Grafeas::V1::SecretKind

Returns Type of secret.

Returns:



45
46
47
48
# File 'proto_docs/grafeas/v1/secret.rb', line 45

class SecretOccurrence
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#locations::Array<::Grafeas::V1::SecretLocation>

Returns Locations where the secret is detected.

Returns:



45
46
47
48
# File 'proto_docs/grafeas/v1/secret.rb', line 45

class SecretOccurrence
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#statuses::Array<::Grafeas::V1::SecretStatus>

Returns Status of the secret.

Returns:



45
46
47
48
# File 'proto_docs/grafeas/v1/secret.rb', line 45

class SecretOccurrence
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end