Class: Grafeas::V1::Version
- Inherits:
-
Object
- Object
- Grafeas::V1::Version
- Extended by:
- Google::Protobuf::MessageExts::ClassMethods
- Includes:
- Google::Protobuf::MessageExts
- Defined in:
- proto_docs/grafeas/v1/package.rb
Overview
Version contains structured information about the version of a package.
Defined Under Namespace
Modules: VersionKind
Instance Attribute Summary collapse
-
#epoch ⇒ ::Integer
Used to correct mistakes in the version numbering scheme.
-
#full_name ⇒ ::String
Human readable version string.
-
#inclusive ⇒ ::Boolean
Whether this version is specifying part of an inclusive range.
-
#kind ⇒ ::Grafeas::V1::Version::VersionKind
Required.
-
#name ⇒ ::String
Required only when version kind is NORMAL.
-
#revision ⇒ ::String
The iteration of the package build from the above version.
Instance Attribute Details
#epoch ⇒ ::Integer
Returns Used to correct mistakes in the version numbering scheme.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'proto_docs/grafeas/v1/package.rb', line 120 class Version include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Whether this is an ordinary package version or a sentinel MIN/MAX version. module VersionKind # Unknown. VERSION_KIND_UNSPECIFIED = 0 # A standard package version. NORMAL = 1 # A special version representing negative infinity. MINIMUM = 2 # A special version representing positive infinity. MAXIMUM = 3 end end |
#full_name ⇒ ::String
Returns Human readable version string. This string is of the form
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'proto_docs/grafeas/v1/package.rb', line 120 class Version include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Whether this is an ordinary package version or a sentinel MIN/MAX version. module VersionKind # Unknown. VERSION_KIND_UNSPECIFIED = 0 # A standard package version. NORMAL = 1 # A special version representing negative infinity. MINIMUM = 2 # A special version representing positive infinity. MAXIMUM = 3 end end |
#inclusive ⇒ ::Boolean
Returns Whether this version is specifying part of an inclusive range. Grafeas does not have the capability to specify version ranges; instead we have fields that specify start version and end versions. At times this is insufficient - we also need to specify whether the version is included in the range or is excluded from the range. This boolean is expected to be set to true when the version is included in a range.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'proto_docs/grafeas/v1/package.rb', line 120 class Version include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Whether this is an ordinary package version or a sentinel MIN/MAX version. module VersionKind # Unknown. VERSION_KIND_UNSPECIFIED = 0 # A standard package version. NORMAL = 1 # A special version representing negative infinity. MINIMUM = 2 # A special version representing positive infinity. MAXIMUM = 3 end end |
#kind ⇒ ::Grafeas::V1::Version::VersionKind
Returns Required. Distinguishes between sentinel MIN/MAX versions and normal versions.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'proto_docs/grafeas/v1/package.rb', line 120 class Version include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Whether this is an ordinary package version or a sentinel MIN/MAX version. module VersionKind # Unknown. VERSION_KIND_UNSPECIFIED = 0 # A standard package version. NORMAL = 1 # A special version representing negative infinity. MINIMUM = 2 # A special version representing positive infinity. MAXIMUM = 3 end end |
#name ⇒ ::String
Returns Required only when version kind is NORMAL. The main part of the version name.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'proto_docs/grafeas/v1/package.rb', line 120 class Version include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Whether this is an ordinary package version or a sentinel MIN/MAX version. module VersionKind # Unknown. VERSION_KIND_UNSPECIFIED = 0 # A standard package version. NORMAL = 1 # A special version representing negative infinity. MINIMUM = 2 # A special version representing positive infinity. MAXIMUM = 3 end end |
#revision ⇒ ::String
Returns The iteration of the package build from the above version.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'proto_docs/grafeas/v1/package.rb', line 120 class Version include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Whether this is an ordinary package version or a sentinel MIN/MAX version. module VersionKind # Unknown. VERSION_KIND_UNSPECIFIED = 0 # A standard package version. NORMAL = 1 # A special version representing negative infinity. MINIMUM = 2 # A special version representing positive infinity. MAXIMUM = 3 end end |