Class: Grafeas::V1::VulnerabilityOccurrence::PackageIssue
- Inherits:
-
Object
- Object
- Grafeas::V1::VulnerabilityOccurrence::PackageIssue
- Extended by:
- Google::Protobuf::MessageExts::ClassMethods
- Includes:
- Google::Protobuf::MessageExts
- Defined in:
- proto_docs/grafeas/v1/vulnerability.rb
Overview
A detail for a distro and package this vulnerability occurrence was found in and its associated fix (if one is available).
Instance Attribute Summary collapse
-
#affected_cpe_uri ⇒ ::String
Required.
-
#affected_package ⇒ ::String
Required.
-
#affected_version ⇒ ::Grafeas::V1::Version
Required.
-
#effective_severity ⇒ ::Grafeas::V1::Severity
readonly
The distro or language system assigned severity for this vulnerability when that is available and note provider assigned severity when it is not available.
-
#fix_available ⇒ ::Boolean
Output only.
-
#fixed_cpe_uri ⇒ ::String
The CPE URI this vulnerability was fixed in.
-
#fixed_package ⇒ ::String
The package this vulnerability was fixed in.
-
#fixed_version ⇒ ::Grafeas::V1::Version
Required.
-
#package_type ⇒ ::String
The type of package (e.g. OS, MAVEN, GO).
Instance Attribute Details
#affected_cpe_uri ⇒ ::String
Returns Required. The CPE URI this vulnerability was found in.
243 244 245 246 |
# File 'proto_docs/grafeas/v1/vulnerability.rb', line 243 class PackageIssue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#affected_package ⇒ ::String
Returns Required. The package this vulnerability was found in.
243 244 245 246 |
# File 'proto_docs/grafeas/v1/vulnerability.rb', line 243 class PackageIssue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#affected_version ⇒ ::Grafeas::V1::Version
Returns Required. The version of the package that is installed on the resource affected by this vulnerability.
243 244 245 246 |
# File 'proto_docs/grafeas/v1/vulnerability.rb', line 243 class PackageIssue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#effective_severity ⇒ ::Grafeas::V1::Severity (readonly)
Returns The distro or language system assigned severity for this vulnerability when that is available and note provider assigned severity when it is not available.
243 244 245 246 |
# File 'proto_docs/grafeas/v1/vulnerability.rb', line 243 class PackageIssue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#fix_available ⇒ ::Boolean
Returns Output only. Whether a fix is available for this package.
243 244 245 246 |
# File 'proto_docs/grafeas/v1/vulnerability.rb', line 243 class PackageIssue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#fixed_cpe_uri ⇒ ::String
Returns The CPE URI this vulnerability was fixed in. It is possible for this to be different from the affected_cpe_uri.
243 244 245 246 |
# File 'proto_docs/grafeas/v1/vulnerability.rb', line 243 class PackageIssue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#fixed_package ⇒ ::String
Returns The package this vulnerability was fixed in. It is possible for this to be different from the affected_package.
243 244 245 246 |
# File 'proto_docs/grafeas/v1/vulnerability.rb', line 243 class PackageIssue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#fixed_version ⇒ ::Grafeas::V1::Version
Returns Required. The version of the package this vulnerability was fixed in. Setting this to VersionKind.MAXIMUM means no fix is yet available.
243 244 245 246 |
# File 'proto_docs/grafeas/v1/vulnerability.rb', line 243 class PackageIssue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#package_type ⇒ ::String
Returns The type of package (e.g. OS, MAVEN, GO).
243 244 245 246 |
# File 'proto_docs/grafeas/v1/vulnerability.rb', line 243 class PackageIssue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |