Class: Grafeas::V1::ExploitPredictionScoringSystem
- Inherits:
-
Object
- Object
- Grafeas::V1::ExploitPredictionScoringSystem
- Extended by:
- Google::Protobuf::MessageExts::ClassMethods
- Includes:
- Google::Protobuf::MessageExts
- Defined in:
- proto_docs/grafeas/v1/risk.rb
Instance Attribute Summary collapse
-
#percentile ⇒ ::Float
The percentile of the current score, the proportion of all scored vulnerabilities with the same or a lower EPSS score.
-
#score ⇒ ::Float
The EPSS score representing the probability [0-1] of exploitation in the wild in the next 30 days.
Instance Attribute Details
#percentile ⇒ ::Float
Returns The percentile of the current score, the proportion of all scored vulnerabilities with the same or a lower EPSS score.
52 53 54 55 |
# File 'proto_docs/grafeas/v1/risk.rb', line 52 class ExploitPredictionScoringSystem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#score ⇒ ::Float
Returns The EPSS score representing the probability [0-1] of exploitation in the wild in the next 30 days.
52 53 54 55 |
# File 'proto_docs/grafeas/v1/risk.rb', line 52 class ExploitPredictionScoringSystem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |