Class: Grafeas::V1::InTotoStatement
- Inherits:
-
Object
- Object
- Grafeas::V1::InTotoStatement
- Extended by:
- Google::Protobuf::MessageExts::ClassMethods
- Includes:
- Google::Protobuf::MessageExts
- Defined in:
- proto_docs/grafeas/v1/intoto_statement.rb
Overview
Spec defined at https://github.com/in-toto/attestation/tree/main/spec#statement The serialized InTotoStatement will be stored as Envelope.payload. Envelope.payloadType is always "application/vnd.in-toto+json".
Instance Attribute Summary collapse
-
#predicate_type ⇒ ::String
https://slsa.dev/provenance/v0.1for SlsaProvenance. -
#provenance ⇒ ::Grafeas::V1::InTotoProvenance
Note: The following fields are mutually exclusive:
provenance,slsa_provenance,slsa_provenance_zero_two. -
#slsa_provenance ⇒ ::Grafeas::V1::SlsaProvenance
Note: The following fields are mutually exclusive:
slsa_provenance,provenance,slsa_provenance_zero_two. -
#slsa_provenance_zero_two ⇒ ::Grafeas::V1::SlsaProvenanceZeroTwo
Note: The following fields are mutually exclusive:
slsa_provenance_zero_two,provenance,slsa_provenance. - #subject ⇒ ::Array<::Grafeas::V1::Subject>
-
#type ⇒ ::String
Always
https://in-toto.io/Statement/v0.1.
Instance Attribute Details
#predicate_type ⇒ ::String
Returns https://slsa.dev/provenance/v0.1 for SlsaProvenance.
43 44 45 46 |
# File 'proto_docs/grafeas/v1/intoto_statement.rb', line 43 class InTotoStatement include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#provenance ⇒ ::Grafeas::V1::InTotoProvenance
Returns Note: The following fields are mutually exclusive: provenance, slsa_provenance, slsa_provenance_zero_two. If a field in that set is populated, all other fields in the set will automatically be cleared.
43 44 45 46 |
# File 'proto_docs/grafeas/v1/intoto_statement.rb', line 43 class InTotoStatement include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#slsa_provenance ⇒ ::Grafeas::V1::SlsaProvenance
Returns Note: The following fields are mutually exclusive: slsa_provenance, provenance, slsa_provenance_zero_two. If a field in that set is populated, all other fields in the set will automatically be cleared.
43 44 45 46 |
# File 'proto_docs/grafeas/v1/intoto_statement.rb', line 43 class InTotoStatement include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#slsa_provenance_zero_two ⇒ ::Grafeas::V1::SlsaProvenanceZeroTwo
Returns Note: The following fields are mutually exclusive: slsa_provenance_zero_two, provenance, slsa_provenance. If a field in that set is populated, all other fields in the set will automatically be cleared.
43 44 45 46 |
# File 'proto_docs/grafeas/v1/intoto_statement.rb', line 43 class InTotoStatement include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#subject ⇒ ::Array<::Grafeas::V1::Subject>
43 44 45 46 |
# File 'proto_docs/grafeas/v1/intoto_statement.rb', line 43 class InTotoStatement include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#type ⇒ ::String
Returns Always https://in-toto.io/Statement/v0.1.
43 44 45 46 |
# File 'proto_docs/grafeas/v1/intoto_statement.rb', line 43 class InTotoStatement include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |