Class: Grafeas::V1::ListNotesRequest

Inherits:
Object
  • Object
show all
Extended by:
Google::Protobuf::MessageExts::ClassMethods
Includes:
Google::Protobuf::MessageExts
Defined in:
proto_docs/grafeas/v1/grafeas.rb

Overview

Request to list notes.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns The filter expression.

Returns:

  • (::String)

    The filter expression.



359
360
361
362
# File 'proto_docs/grafeas/v1/grafeas.rb', line 359

class ListNotesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Number of notes to return in the list. Must be positive. Max allowed page size is 1000. If not specified, page size defaults to 20.

Returns:

  • (::Integer)

    Number of notes to return in the list. Must be positive. Max allowed page size is 1000. If not specified, page size defaults to 20.



359
360
361
362
# File 'proto_docs/grafeas/v1/grafeas.rb', line 359

class ListNotesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Token to provide to skip to a particular spot in the list.

Returns:

  • (::String)

    Token to provide to skip to a particular spot in the list.



359
360
361
362
# File 'proto_docs/grafeas/v1/grafeas.rb', line 359

class ListNotesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns The name of the project to list notes for in the form of projects/[PROJECT_ID].

Returns:

  • (::String)

    The name of the project to list notes for in the form of projects/[PROJECT_ID].



359
360
361
362
# File 'proto_docs/grafeas/v1/grafeas.rb', line 359

class ListNotesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#return_partial_success::Boolean

Returns If set, the request will return all reachable Notes and report all unreachable regions in the unreachable field in the response.

Only applicable for requests in the global region.

Returns:

  • (::Boolean)

    If set, the request will return all reachable Notes and report all unreachable regions in the unreachable field in the response.

    Only applicable for requests in the global region.



359
360
361
362
# File 'proto_docs/grafeas/v1/grafeas.rb', line 359

class ListNotesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end