Class: Grafeas::V1::Occurrence
- Inherits:
-
Object
- Object
- Grafeas::V1::Occurrence
- Extended by:
- Google::Protobuf::MessageExts::ClassMethods
- Includes:
- Google::Protobuf::MessageExts
- Defined in:
- proto_docs/grafeas/v1/grafeas.rb
Overview
An instance of an analysis type that has been found on a resource.
Instance Attribute Summary collapse
-
#attestation ⇒ ::Grafeas::V1::AttestationOccurrence
Describes an attestation of an artifact.
-
#build ⇒ ::Grafeas::V1::BuildOccurrence
Describes a verifiable build.
-
#compliance ⇒ ::Grafeas::V1::ComplianceOccurrence
Describes a compliance violation on a linked resource.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
Output only.
-
#deployment ⇒ ::Grafeas::V1::DeploymentOccurrence
Describes the deployment of an artifact on a runtime.
-
#discovery ⇒ ::Grafeas::V1::DiscoveryOccurrence
Describes when a resource was discovered.
-
#dsse_attestation ⇒ ::Grafeas::V1::DSSEAttestationOccurrence
Describes an attestation of an artifact using dsse.
- #envelope ⇒ ::Grafeas::V1::Envelope
-
#image ⇒ ::Grafeas::V1::ImageOccurrence
Describes how this resource derives from the basis in the associated note.
-
#kind ⇒ ::Grafeas::V1::NoteKind
Output only.
-
#name ⇒ ::String
Output only.
-
#note_name ⇒ ::String
Required.
-
#package ⇒ ::Grafeas::V1::PackageOccurrence
Describes the installation of a package on the linked resource.
-
#remediation ⇒ ::String
A description of actions that can be taken to remedy the note.
-
#resource_uri ⇒ ::String
Required.
-
#sbom_reference ⇒ ::Grafeas::V1::SBOMReferenceOccurrence
Describes a specific SBOM reference occurrences.
-
#secret ⇒ ::Grafeas::V1::SecretOccurrence
Describes a secret.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
Output only.
-
#upgrade ⇒ ::Grafeas::V1::UpgradeOccurrence
Describes an available package upgrade on the linked resource.
-
#vulnerability ⇒ ::Grafeas::V1::VulnerabilityOccurrence
Describes a security vulnerability.
Instance Attribute Details
#attestation ⇒ ::Grafeas::V1::AttestationOccurrence
Returns Describes an attestation of an artifact.
Note: The following fields are mutually exclusive: attestation, vulnerability, build, image, package, deployment, discovery, upgrade, compliance, dsse_attestation, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.
114 115 116 117 |
# File 'proto_docs/grafeas/v1/grafeas.rb', line 114 class Occurrence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#build ⇒ ::Grafeas::V1::BuildOccurrence
Returns Describes a verifiable build.
Note: The following fields are mutually exclusive: build, vulnerability, image, package, deployment, discovery, attestation, upgrade, compliance, dsse_attestation, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.
114 115 116 117 |
# File 'proto_docs/grafeas/v1/grafeas.rb', line 114 class Occurrence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#compliance ⇒ ::Grafeas::V1::ComplianceOccurrence
Returns Describes a compliance violation on a linked resource.
Note: The following fields are mutually exclusive: compliance, vulnerability, build, image, package, deployment, discovery, attestation, upgrade, dsse_attestation, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.
114 115 116 117 |
# File 'proto_docs/grafeas/v1/grafeas.rb', line 114 class Occurrence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#create_time ⇒ ::Google::Protobuf::Timestamp
Returns Output only. The time this occurrence was created.
114 115 116 117 |
# File 'proto_docs/grafeas/v1/grafeas.rb', line 114 class Occurrence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#deployment ⇒ ::Grafeas::V1::DeploymentOccurrence
Returns Describes the deployment of an artifact on a runtime.
Note: The following fields are mutually exclusive: deployment, vulnerability, build, image, package, discovery, attestation, upgrade, compliance, dsse_attestation, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.
114 115 116 117 |
# File 'proto_docs/grafeas/v1/grafeas.rb', line 114 class Occurrence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#discovery ⇒ ::Grafeas::V1::DiscoveryOccurrence
Returns Describes when a resource was discovered.
Note: The following fields are mutually exclusive: discovery, vulnerability, build, image, package, deployment, attestation, upgrade, compliance, dsse_attestation, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.
114 115 116 117 |
# File 'proto_docs/grafeas/v1/grafeas.rb', line 114 class Occurrence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#dsse_attestation ⇒ ::Grafeas::V1::DSSEAttestationOccurrence
Returns Describes an attestation of an artifact using dsse.
Note: The following fields are mutually exclusive: dsse_attestation, vulnerability, build, image, package, deployment, discovery, attestation, upgrade, compliance, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.
114 115 116 117 |
# File 'proto_docs/grafeas/v1/grafeas.rb', line 114 class Occurrence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#envelope ⇒ ::Grafeas::V1::Envelope
114 115 116 117 |
# File 'proto_docs/grafeas/v1/grafeas.rb', line 114 class Occurrence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#image ⇒ ::Grafeas::V1::ImageOccurrence
Returns Describes how this resource derives from the basis in the associated note.
Note: The following fields are mutually exclusive: image, vulnerability, build, package, deployment, discovery, attestation, upgrade, compliance, dsse_attestation, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.
114 115 116 117 |
# File 'proto_docs/grafeas/v1/grafeas.rb', line 114 class Occurrence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::Grafeas::V1::NoteKind
Returns Output only. This explicitly denotes which of the occurrence details are specified. This field can be used as a filter in list requests.
114 115 116 117 |
# File 'proto_docs/grafeas/v1/grafeas.rb', line 114 class Occurrence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Output only. The name of the occurrence in the form of
projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID].
114 115 116 117 |
# File 'proto_docs/grafeas/v1/grafeas.rb', line 114 class Occurrence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#note_name ⇒ ::String
Returns Required. Immutable. The analysis note associated with this occurrence, in
the form of projects/[PROVIDER_ID]/notes/[NOTE_ID]. This field can be
used as a filter in list requests.
114 115 116 117 |
# File 'proto_docs/grafeas/v1/grafeas.rb', line 114 class Occurrence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#package ⇒ ::Grafeas::V1::PackageOccurrence
Returns Describes the installation of a package on the linked resource.
Note: The following fields are mutually exclusive: package, vulnerability, build, image, deployment, discovery, attestation, upgrade, compliance, dsse_attestation, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.
114 115 116 117 |
# File 'proto_docs/grafeas/v1/grafeas.rb', line 114 class Occurrence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#remediation ⇒ ::String
Returns A description of actions that can be taken to remedy the note.
114 115 116 117 |
# File 'proto_docs/grafeas/v1/grafeas.rb', line 114 class Occurrence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resource_uri ⇒ ::String
Returns Required. Immutable. A URI that represents the resource for which the
occurrence applies. For example,
https://gcr.io/project/image@sha256:123abc for a Docker image.
114 115 116 117 |
# File 'proto_docs/grafeas/v1/grafeas.rb', line 114 class Occurrence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sbom_reference ⇒ ::Grafeas::V1::SBOMReferenceOccurrence
Returns Describes a specific SBOM reference occurrences.
Note: The following fields are mutually exclusive: sbom_reference, vulnerability, build, image, package, deployment, discovery, attestation, upgrade, compliance, dsse_attestation, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.
114 115 116 117 |
# File 'proto_docs/grafeas/v1/grafeas.rb', line 114 class Occurrence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#secret ⇒ ::Grafeas::V1::SecretOccurrence
Returns Describes a secret.
Note: The following fields are mutually exclusive: secret, vulnerability, build, image, package, deployment, discovery, attestation, upgrade, compliance, dsse_attestation, sbom_reference. If a field in that set is populated, all other fields in the set will automatically be cleared.
114 115 116 117 |
# File 'proto_docs/grafeas/v1/grafeas.rb', line 114 class Occurrence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_time ⇒ ::Google::Protobuf::Timestamp
Returns Output only. The time this occurrence was last updated.
114 115 116 117 |
# File 'proto_docs/grafeas/v1/grafeas.rb', line 114 class Occurrence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#upgrade ⇒ ::Grafeas::V1::UpgradeOccurrence
Returns Describes an available package upgrade on the linked resource.
Note: The following fields are mutually exclusive: upgrade, vulnerability, build, image, package, deployment, discovery, attestation, compliance, dsse_attestation, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.
114 115 116 117 |
# File 'proto_docs/grafeas/v1/grafeas.rb', line 114 class Occurrence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#vulnerability ⇒ ::Grafeas::V1::VulnerabilityOccurrence
Returns Describes a security vulnerability.
Note: The following fields are mutually exclusive: vulnerability, build, image, package, deployment, discovery, attestation, upgrade, compliance, dsse_attestation, sbom_reference, secret. If a field in that set is populated, all other fields in the set will automatically be cleared.
114 115 116 117 |
# File 'proto_docs/grafeas/v1/grafeas.rb', line 114 class Occurrence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |