Class: Grafeas::V1::RepoId
- Inherits:
-
Object
- Object
- Grafeas::V1::RepoId
- Extended by:
- Google::Protobuf::MessageExts::ClassMethods
- Includes:
- Google::Protobuf::MessageExts
- Defined in:
- proto_docs/grafeas/v1/provenance.rb
Overview
A unique identifier for a Cloud Repo.
Instance Attribute Summary collapse
-
#project_repo_id ⇒ ::Grafeas::V1::ProjectRepoId
A combination of a project ID and a repo name.
-
#uid ⇒ ::String
A server-assigned, globally unique identifier.
Instance Attribute Details
#project_repo_id ⇒ ::Grafeas::V1::ProjectRepoId
Returns A combination of a project ID and a repo name.
Note: The following fields are mutually exclusive: project_repo_id, uid. If a field in that set is populated, all other fields in the set will automatically be cleared.
318 319 320 321 |
# File 'proto_docs/grafeas/v1/provenance.rb', line 318 class RepoId include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#uid ⇒ ::String
Returns A server-assigned, globally unique identifier.
Note: The following fields are mutually exclusive: uid, project_repo_id. If a field in that set is populated, all other fields in the set will automatically be cleared.
318 319 320 321 |
# File 'proto_docs/grafeas/v1/provenance.rb', line 318 class RepoId include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |