Class: Grafeas::V1::Risk
- Inherits:
-
Object
- Object
- Grafeas::V1::Risk
- Extended by:
- Google::Protobuf::MessageExts::ClassMethods
- Includes:
- Google::Protobuf::MessageExts
- Defined in:
- proto_docs/grafeas/v1/risk.rb
Instance Attribute Summary collapse
-
#cisa_kev ⇒ ::Grafeas::V1::CISAKnownExploitedVulnerabilities
CISA maintains the authoritative source of vulnerabilities that have been exploited in the wild.
-
#epss ⇒ ::Grafeas::V1::ExploitPredictionScoringSystem
The Exploit Prediction Scoring System (EPSS) estimates the likelihood (probability) that a software vulnerability will be exploited in the wild.
Instance Attribute Details
#cisa_kev ⇒ ::Grafeas::V1::CISAKnownExploitedVulnerabilities
Returns CISA maintains the authoritative source of vulnerabilities that have been exploited in the wild.
30 31 32 33 |
# File 'proto_docs/grafeas/v1/risk.rb', line 30 class Risk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#epss ⇒ ::Grafeas::V1::ExploitPredictionScoringSystem
Returns The Exploit Prediction Scoring System (EPSS) estimates the likelihood (probability) that a software vulnerability will be exploited in the wild.
30 31 32 33 |
# File 'proto_docs/grafeas/v1/risk.rb', line 30 class Risk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |