Class: Grafeas::V1::SourceContext
- Inherits:
-
Object
- Object
- Grafeas::V1::SourceContext
- Extended by:
- Google::Protobuf::MessageExts::ClassMethods
- Includes:
- Google::Protobuf::MessageExts
- Defined in:
- proto_docs/grafeas/v1/provenance.rb
Overview
A SourceContext is a reference to a tree of files. A SourceContext together with a path point to a unique revision of a single file or directory.
Defined Under Namespace
Classes: LabelsEntry
Instance Attribute Summary collapse
-
#cloud_repo ⇒ ::Grafeas::V1::CloudRepoSourceContext
A SourceContext referring to a revision in a Google Cloud Source Repo.
-
#gerrit ⇒ ::Grafeas::V1::GerritSourceContext
A SourceContext referring to a Gerrit project.
-
#git ⇒ ::Grafeas::V1::GitSourceContext
A SourceContext referring to any third party Git repo (e.g., GitHub).
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Labels with user defined metadata.
Instance Attribute Details
#cloud_repo ⇒ ::Grafeas::V1::CloudRepoSourceContext
Returns A SourceContext referring to a revision in a Google Cloud Source Repo.
Note: The following fields are mutually exclusive: cloud_repo, gerrit, git. If a field in that set is populated, all other fields in the set will automatically be cleared.
208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'proto_docs/grafeas/v1/provenance.rb', line 208 class SourceContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#gerrit ⇒ ::Grafeas::V1::GerritSourceContext
Returns A SourceContext referring to a Gerrit project.
Note: The following fields are mutually exclusive: gerrit, cloud_repo, git. If a field in that set is populated, all other fields in the set will automatically be cleared.
208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'proto_docs/grafeas/v1/provenance.rb', line 208 class SourceContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#git ⇒ ::Grafeas::V1::GitSourceContext
Returns A SourceContext referring to any third party Git repo (e.g., GitHub).
Note: The following fields are mutually exclusive: git, cloud_repo, gerrit. If a field in that set is populated, all other fields in the set will automatically be cleared.
208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'proto_docs/grafeas/v1/provenance.rb', line 208 class SourceContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Labels with user defined metadata.
208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'proto_docs/grafeas/v1/provenance.rb', line 208 class SourceContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |