Class: Grafeas::V1::VulnerabilityOccurrence::CVSSV3
- Inherits:
-
Object
- Object
- Grafeas::V1::VulnerabilityOccurrence::CVSSV3
- Extended by:
- Google::Protobuf::MessageExts::ClassMethods
- Includes:
- Google::Protobuf::MessageExts
- Defined in:
- proto_docs/grafeas/v1/vulnerability.rb
Overview
The CVSS v3 score for this vulnerability.
Instance Attribute Summary collapse
-
#base_score ⇒ ::Float
The base score for for this vulnerability according to cvss v3.
-
#severity ⇒ ::Grafeas::V1::Severity
The severity rating assigned to this vulnerability by vulnerability provider.
Instance Attribute Details
#base_score ⇒ ::Float
Returns The base score for for this vulnerability according to cvss v3.
214 215 216 217 |
# File 'proto_docs/grafeas/v1/vulnerability.rb', line 214 class CVSSV3 include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#severity ⇒ ::Grafeas::V1::Severity
Returns The severity rating assigned to this vulnerability by vulnerability provider.
214 215 216 217 |
# File 'proto_docs/grafeas/v1/vulnerability.rb', line 214 class CVSSV3 include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |